(***********************************************************************)
(*                                                                     *)
(*                             Pio (OCaml)                             *)
(*                                                                     *)
(*                    Polyglot Input/Output Library                    *)
(*                                                                     *)
(*               EPI Pomdapi, INRIA Paris - Rocquencourt               *)
(*                                                                     *)
(*  Copyright 2005-2014 INRIA.                                         *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  All rights reserved. This file is distributed only by permission.  *)
(*                                                                     *)
(*  Francois Clement <Francois.Clement@inria.fr>                       *)
(*  Pierre Weis <Pierre.Weis@inria.fr>                                 *)
(*                                                                     *)
(***********************************************************************)

(* $Id: value_type_def.mli,v 1.7 2014/01/10 19:22:10 fclement Exp $ *)

(** The private definition of typed-values types. *)

(** This is the private part of the Caml type that defines the types of the
basic entities used inside communications, the so-called typed-values. *)

type value_type = private
| Scalar_type of scalar_type
| Vector_type of scalar_type
| Matrix_type of scalar_type

and scalar_type = private
| Bool_type
| String_type
| Int_type | Native_int_type | Int32_type | Int64_type
| Float_type | Float_bin_type
| Couple_type of scalar_type * scalar_type
| Triple_type of scalar_type * scalar_type * scalar_type;;
(** The private part of the Caml type of typed-values types. *)

val bool_type : scalar_type;;
val string_type : scalar_type;;
val int_type : scalar_type;;
val native_int_type : scalar_type;;
val int32_type : scalar_type;;
val int64_type : scalar_type;;
val float_type : scalar_type;;
val float_bin_type : scalar_type;;

val couple_type : scalar_type * scalar_type -> scalar_type;;

val triple_type : scalar_type * scalar_type * scalar_type -> scalar_type;;
(** The public construction functions for [scalar_type], the Caml type that
defines the types of scalars. *)

val scalar_type : scalar_type -> value_type;;
val vector_type : scalar_type -> value_type;;
val matrix_type : scalar_type -> value_type;;
(** The public construction functions for [value_type], the Caml type that
defines the types of typed-values. *)
