CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC
C                                                                     C
C                            Pio (Fortran)                            C
C                                                                     C
C                    Polyglot Input/Output Library                    C
C                                                                     C
C               EPI Pomdapi, INRIA Paris - Rocquencourt               C
C                                                                     C
C  Copyright 2005-2014 INRIA.                                         C
C  Institut National de Recherche en Informatique et en Automatique.  C
C  All rights reserved. This file is distributed only by permission.  C
C                                                                     C
C  Francois Clement <Francois.Clement@inria.fr>                       C
C  Pierre Weis <Pierre.Weis@inria.fr>                                 C
C  Hend Ben Ameur <hbenameur@yahoo.ca>                                C
C                                                                     C
CCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCCC

      
C $Id: print_typed_value.fpp,v 1.8 2014/03/13 20:08:47 fclement Exp $
      
C     
C     Routines to print a typed value into the printing buffer.
C     
      
#include "pio_constants.h"
      
      subroutine buffer_print_size(sbr, sz)
C     Print a Size in the sens of the PIO library.
      
      implicit none
      
      include 'buffers_definition.fh'
      
C     Input arguments.
      character sbr*(*)
      integer sz
      
C     External function.
      logical pio_get_debug_mode
      
      if (pio_get_debug_mode()) then
         write(PIO_DEBUG, *) '[Pio/Fortran] In ', sbr, ': size = ', sz
      endif
      
      call buffer_print_char(sbr, '<')
      call buffer_print_natural(sbr, sz)
      call buffer_print_char(sbr, '>')
      
      return
      end
      
      
      subroutine print_string_value(i, j, k, sz, l, tup)
C     Print a string value.
      
      implicit none
      
C     Input arguments.
      integer i, j, k, sz, l, tup
      
C     Local variables.
      character sbr*18, sv(MAX_STRING_ITEMS)*MAX_STRING_LENGTH, c
      integer nl, lenv(MAX_STRING_ITEMS), m
      
C     External functions.
      logical pio_get_debug_mode
      character int_to_char
      
      sbr = 'print_string_value'
      
      if (pio_get_debug_mode()) then
         write(PIO_DEBUG, *) '[Pio/Fortran] In ', sbr,
     +        ', i = ', i, ', j = ', j, ', k = ', k, ', l = ', l
      endif
      
      if (sz .ne. 1 .and. tup .ne. 1) then
         call error_assertion_failure
     +        (sbr, 'vectors of tuple of strings are forbidden.')
      endif
      if (k .ne. 1 .and. l .ne. 1) then
         call error_assertion_failure
     +        (sbr, 'vectors of tuple of strings are forbidden.')
      endif
      if (j .ne. 1) then
         call error_assertion_failure
     +        (sbr, 'matrices of strings are forbidden.')
      endif

      call fetch_value_lengths(sbr, PIO_OUT, i, nl, lenv)
      call rand_fetch_string_compound_value
     +     (sbr, PIO_OUT, i, nl, lenv, sv)
      
C     Newline character '\n'.
      c = int_to_char(10)
      
C     m = k when l=1, m = l when k=1.
      m = k*l
      
      call buffer_print_size(sbr, lenv(m))
      call buffer_print_char(sbr, c)
      call buffer_print_delimited_string(sbr, sv(m), lenv(m))
      
      return
      end
      
      
      subroutine print_int_value(i, j, k, sz, l, tup)
C     Print an integer value.
      
      implicit none
      
C     Input arguments.
      integer i, j, k, sz, l, tup
      
C     Local variables.
      character sbr*15
      integer idatum
      
C     External functions.
      logical pio_get_debug_mode
      integer rand_fetch_int_value
      
      sbr = 'print_int_value'
      
      if (pio_get_debug_mode()) then
         write(PIO_DEBUG, *) '[Pio/Fortran] In ', sbr,
     +        ', i = ', i, ', j = ', j, ', k = ', k, ', l = ', l
      endif
      
      idatum =
     +     rand_fetch_int_value(sbr, PIO_OUT, i, j, k, sz, l, tup)
      
      call buffer_print_int(sbr, idatum)
      
      return
      end
      
      
      subroutine print_float_value(i, j, k, sz, l, tup)
C     Print a float value.
      
      implicit none
      
C     Input arguments.
      integer i, j, k, sz, l, tup
      
C     Local variables.
      character sbr*17
      FLOAT fdatum
      
C     External functions.
      logical pio_get_debug_mode, pio_communication_mode_is_binary
      FLOAT rand_fetch_float_value
      
      sbr = 'print_float_value'
      
      if (pio_get_debug_mode()) then
         write(PIO_DEBUG, *) '[Pio/Fortran] In ', sbr,
     +        ', i = ', i, ', j = ', j, ', k = ', k, ', l = ', l
      endif
      
      fdatum =
     +     rand_fetch_float_value(sbr, PIO_OUT, i, j, k, sz, l, tup)
      
      if (pio_communication_mode_is_binary()) then
         call buffer_print_binary_float(sbr, fdatum)
      else
         call buffer_print_ascii_float(sbr, fdatum)
      endif
      
      return
      end
      
      
      subroutine print_simple(i, j, k, sz, l, tup, typ)
C     Print a simple value.
      
      implicit none
      
C     Input arguments.
      integer i, j, k, sz, l, tup, typ
      
C     Local variable.
      character sbr*12
      
C     External function.
      logical pio_get_debug_mode
      
      sbr = 'print_simple'
      
      if (pio_get_debug_mode()) then
         write(PIO_DEBUG, *) '[Pio/Fortran] In ', sbr,
     +        ', i = ', i, ', j = ', j, ', k = ', k, ', l = ', l,
     +        ', typ = ', typ
      endif
      
      if (typ .eq. SSTRING) then
         
         call print_string_value(i, j, k, sz, l, tup)
         
      else if (typ .eq. SINT) then
         
         call print_int_value(i, j, k, sz, l, tup)
         
      else if (typ .eq. SFLOAT) then
         
         call print_float_value(i, j, k, sz, l, tup)
         
      else
         
C     impossible, already checked in print_scalar
         write(PIO_STDERR, *) '[Pio/Fortran] typ = ', typ
         call error_internal_error(sbr)
         
      endif
      
      return
      end
      
      
      subroutine print_couple(i, j, k, sz, typ)
C     Print a couple value of type typ.
      
      implicit none
      
C     Input arguments.
      integer i, j, k, sz, typ
      
C     Local variables.
      character sbr*12
      integer item_typ
      
C     External function.
      logical pio_get_debug_mode
      
      sbr = 'print_couple'
      
      if (pio_get_debug_mode()) then
         write(PIO_DEBUG, *) '[Pio/Fortran] In ', sbr,
     +        ', i = ', i, ', j = ', j, ', k = ', k, ', typ = ', typ
      endif
      
      item_typ = MAKE_COUPLE_ITEM_TYPE(typ)
      
      call print_simple(i, j, k, sz, 1, 2, item_typ)
      call buffer_print_string(sbr, 2, ', ')
      call print_simple(i, j, k, sz, 2, 2, item_typ)
      
      return
      end
      
      
      subroutine print_triple(i, j, k, sz, typ)
C     Print a triple value of type typ.
      
      implicit none
      
C     Input arguments.
      integer i, j, k, sz, typ
      
C     Local variables.
      character sbr*12
      integer item_typ
      
C     External function.
      logical pio_get_debug_mode
      
      sbr = 'print_triple'
      
      if (pio_get_debug_mode()) then
         write(PIO_DEBUG, *) '[Pio/Fortran] In ', sbr,
     +        ', i = ', i, ', j = ', j, ', k = ', k, ', typ = ', typ
      endif
      
      item_typ = MAKE_TRIPLE_ITEM_TYPE(typ)
      
      call print_simple(i, j, k, sz, 1, 3, item_typ)
      call buffer_print_string(sbr, 2, ', ')
      call print_simple(i, j, k, sz, 2, 3, item_typ)
      call buffer_print_string(sbr, 2, ', ')
      call print_simple(i, j, k, sz, 3, 3, item_typ)
      
      return
      end
      
      
      subroutine print_tuple(i, j, k, sz, typ)
C     Print a tuple value of type typ.
      
      implicit none
      
C     Input arguments.
      integer i, j, k, sz, typ
      
C     Local variables.
      character sbr*11
      
C     External functions.
      logical pio_get_debug_mode, is_scalar_couple_type
      
      sbr = 'print_tuple'
      
      if (pio_get_debug_mode()) then
         write(PIO_DEBUG, *) '[Pio/Fortran] In ', sbr,
     +        ', i = ', i, ', j = ', j, ', k = ', k, ', typ = ', typ
      endif
      
      call buffer_print_char(sbr, '(')
      
      if (is_scalar_couple_type(typ)) then
         call print_couple(i, j, k, sz, typ)
      else
         call print_triple(i, j, k, sz, typ)
      endif
      
      call buffer_print_char(sbr, ')')
      
      return
      end
      
      
      subroutine print_scalar(i, j, k, sz, typ)
C     Print a scalar value.
      
      implicit none
      
C     Input arguments.
      integer i, j, k, sz, typ
      
C     Local variable.
      character sbr*12
      
C     External functions.
      logical pio_get_debug_mode, is_scalar_simple_type
      
      sbr = 'print_scalar'
      
      if (pio_get_debug_mode()) then
         write(PIO_DEBUG, *) '[Pio/Fortran] In ', sbr,
     +        ', i = ', i, ', j = ', j, ', k = ', k, ', typ = ', typ
      endif
      
      if (is_scalar_simple_type(typ)) then
         call print_simple(i, j, k, sz, 1, 1, typ)
      else
         call print_tuple(i, j, k, sz, typ)
      endif
      
      return
      end
      
      
      subroutine print_scalar_item(oc, i, j, k, sz, typ)
C     Print a scalar item.
      
      implicit none
      
C     Input arguments.
      integer oc, i, j, k, sz, typ
      
C     Local variable.
      character sbr*17
      
      sbr = 'print_scalar_item'
      
      call print_scalar(i, j, k, sz, typ)
      
      call buffer_print_char(sbr, ';')
      
C      call buffer_print_newline(sbr)
C     We omit previous call to buffer_print_newline since we must flush
C     the  buffer (in order to keep it small enough), and flush_buffer
C     adds an end_of_line marker (because we use a formatted write to
C     flush the buffer).
      call flush_buffer(sbr, oc)
      
      return
      end
      
      
      subroutine print_scalar_items(oc, i, j, typ, sz)
C     Print scalar items of an array.
      
C     Input arguments.
      integer oc, i, j, typ, sz
      
C     Local variable.
      integer k
      
      do k = 1, sz
         call print_scalar_item(oc, i, j, k, sz, typ)
      enddo
      
      return
      end
      
      
      subroutine print_vector(oc, i, typ)
C     Print a vector of type typ.
      
      implicit none
      
C     Input arguments.
      integer oc, i, typ
      
C     Local variables.
      character sbr*12
      integer item_typ, sz(1)
      
C     External function.
      logical pio_get_debug_mode
      
      sbr = 'print_vector'
      
      item_typ = MAKE_VECTOR_ITEM_TYPE(typ)
      if (pio_get_debug_mode()) then
         write(PIO_DEBUG, *) '[Pio/Fortran] In ', sbr, ', ',
     +        'typ = ', typ, 'item_typ = ', item_typ
      endif
      
      call buffer_print_string(sbr, 2, '[1')
      call buffer_print_newline(sbr)
      
      call fetch_value_sizes(sbr, PIO_OUT, i, sz)
      
      call buffer_print_size(sbr, sz(1))
      call buffer_print_newline(sbr)
      
      call print_scalar_items(oc, i, 1, item_typ, sz(1))
      
      call buffer_print_string(sbr, 2, '1]')
      
      return
      end
      
      
      subroutine print_multi_d_sizes(p, sizev)
C     Print the sizes of a multi dimensional array value.
      
      implicit none
      
C     Input arguments.
      integer p
      integer sizev(MAX_ARRAY_DIMENSION)
      
C     Local variable.
      character sbr*19
      
      sbr = 'print_multi_d_sizes'
      
      call buffer_print_char(sbr, '<')
      call buffer_print_natural_list2(sbr, p, sizev)
      call buffer_print_char(sbr, '>')
      
      return
      end
      
      
      subroutine print_multi_d_layout(pv, lkv, layoutv)
C     Print the layout of a multi dimensional array value.
      
      implicit none
      
C     Input arguments.
      integer pv, lkv, layoutv(MAX_ARRAY_DIMENSION)
      
C     Local variable.
      character sbr*20
      
      sbr = 'print_multi_d_layout'
      
      if (lkv .eq. C_LAYOUT_KIND) then
         call buffer_print_char(sbr, 'C')
      else if (lkv .eq. FORTRAN_LAYOUT_KIND) then
         call buffer_print_char(sbr, 'F')
      else if (lkv .eq. PERMUTATION_LAYOUT_KIND) then
         call buffer_print_natural_list2(sbr, pv, layoutv)
      endif
      
      return
      end
      
      
      subroutine print_row(oc, i, j, typ, sz)
C     Print the jth row (of size sz) of the ith value which is a multi
C     dimensional array value.
      
      implicit none
      
C     Input arguments.
      integer oc, i, j, typ, sz
      
C     Local variable.
      character sbr*9
      
      sbr = 'print_row'
      
      call buffer_print_string(sbr, 2, '[|')
      call buffer_print_newline(sbr)
      call print_scalar_items(oc, i, j, typ, sz)
      call buffer_print_string(sbr, 2, '|]')
      
      return
      end
      
      
      subroutine print_row_item(oc, i, j, typ, sz)
C     Print the jth row item (of size sz) of the ith value which is a multi
C     dimensional array value.
      
      implicit none
      
C     Input arguments.
      integer oc, i, j, typ, sz
      
C     Local variable.
      character sbr*14
      
      sbr = 'print_row_item'
      
      call print_row(oc, i, j, typ, sz)
      call buffer_print_char(sbr, ';')
      call buffer_print_newline(sbr)
      
      return
      end
      
      
      subroutine print_row_items(oc, i, typ, pv, sizev, layoutv)
C     Print the rows of the ith value which is a multi dimensional
C     array value of dimension pv with size sizev(j) in direction j.
      
      implicit none
      
C     Input arguments.
      integer oc, i, typ, pv, sizev(*), layoutv(*)
      
C     Local variables.
      character sbr*15
      integer nb_row, sz, j
      
      sbr = 'print_row_items'
      
      call row_number_and_size
     +     (sbr, 'printed', pv, sizev, layoutv, nb_row, sz)
      
      do j = 1, nb_row
         call print_row_item(oc, i, j, typ, sz)
      enddo
      
      return
      end
      
      
      subroutine print_multi_d(oc, i, typ)
C     Print ith value which is a multi dimensional array value of type
C     typ.
      
      implicit none
      
C     Input arguments.
      integer oc, i, typ
      
C     Local variables.
      character sbr*13
      integer item_typ, pv, sizev(MAX_ARRAY_DIMENSION)
      integer lkv, layoutv(MAX_ARRAY_DIMENSION)
      
C     External functions.
      logical pio_get_debug_mode
      integer fetch_value_dimension
      
      sbr = 'print_multi_d'
      
      item_typ = MAKE_MULTI_D_ITEM_TYPE(typ)
      if (pio_get_debug_mode()) then
         write(PIO_DEBUG, *) '[Pio/Fortran] In ', sbr, ', ',
     +        'typ = ', typ, 'item_typ = ', item_typ
      endif
      
      pv = fetch_value_dimension(sbr, PIO_OUT, i)
      
      call buffer_print_char(sbr, '[')
      call buffer_print_natural(sbr, pv)
      call buffer_print_newline(sbr)
      
      call fetch_value_sizes(sbr, PIO_OUT, i, sizev)
      call fetch_value_layout(sbr, PIO_OUT, i, lkv, layoutv)
      
      call print_multi_d_sizes(pv, sizev)
      call buffer_print_newline(sbr)
      call print_multi_d_layout(pv, lkv, layoutv)
      call buffer_print_newline(sbr)
      
      call print_row_items(oc, i, item_typ, pv, sizev, layoutv)
      
      call buffer_print_natural(sbr, pv)
      call buffer_print_char(sbr, ']')
      
      return
      end
      
      
      subroutine print_array(oc, i, typ)
C     Print ith value which is an array value of type typ.
C     We already know that typ is not a scalar type.
      
      implicit none
      
C     Input arguments.
      integer oc, i, typ
      
C     External function.
      logical is_vector_type
      
      if (is_vector_type(typ)) then
         call print_vector(oc, i, typ)
      else
         call print_multi_d(oc, i, typ)
      endif
      
      return
      end
      
      
      subroutine print_array_item(oc, i, typ)
C     Print ith value which is an array value of type typ.
C     We already know that typ is not a scalar type.
      
      implicit none
      
C     Input arguments.
      integer oc, i, typ
      
C     Local variable.
      character sbr*16
      
      sbr = 'print_array_item'
      
      call print_array(oc, i, typ)
      call buffer_print_char(sbr, ';')
      call buffer_print_newline(sbr)
      
      return
      end
      
      
      subroutine print_value(oc, i, typ)
C     Print the ith value which has type typ.
      
      implicit none
      
C     Input arguments.
      integer oc, i, typ
      
C     External function.
      logical is_scalar_type
      
      if (is_scalar_type(typ)) then
         call print_scalar_item(oc, i, 1, 1, 1, typ)
      else
         call print_array_item(oc, i, typ)
      endif
      
      return
      end
      
      
      subroutine print_value_begin(sbr)
C     Print the "begin" marker of a typed value.
      
      implicit none
      
C     Input argument.
      character sbr*(*)
      
      call buffer_print_string(sbr, 5, 'begin')
      
      return
      end
      
      
      subroutine print_value_end(sbr)
C     Print the "end" marker of a typed value.
      
      implicit none
      
C     Input argument.
      character sbr*(*)
      
      call buffer_print_string(sbr, 3, 'end')
      
      return
      end
      
      
      subroutine print_typed_value(oc, i)
C     Print a typed value.
      
      implicit none
      
C     Input arguments.
      integer oc, i
      
C     Local variables.
      character sbr*17
      integer typ
      
C     External functions.
      logical pio_get_debug_mode
      integer fetch_value_type
      
      sbr = 'print_typed_value'
   
      if (pio_get_debug_mode()) then
         write(PIO_DEBUG, *)
     +        '[Pio/Fortran] In print_typed_value, i = ', i
      endif
      
      call print_value_begin(sbr)
      call buffer_print_newline(sbr)
      
      typ = fetch_value_type(sbr, PIO_OUT, i)
      
      call print_value_type(i, typ)
      call buffer_print_newline(sbr)
      
      if (pio_get_debug_mode()) then
         write(PIO_DEBUG, *) '[Pio/Fortran] Back to print_typed_value'
      endif
      
      call print_value(oc, i, typ)
      
      if (pio_get_debug_mode()) then
         write(PIO_DEBUG, *) '[Pio/Fortran] value printed'
      endif
      
      call print_value_end(sbr)
      call buffer_print_newline(sbr)
      call buffer_print_newline(sbr)
      
      return
      end
